@@ -1,5 +1,5 @@
 /*
- * $Id: sgtk-util.c,v 1.14.2.1 2004/05/11 10:54:34 jylefort Exp $
+ * $Id: sgtk-util.c,v 1.14.2.2 2004/05/11 15:40:41 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,8 +32,8 @@
  */
 
 #include "config.h"
-#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
+#include "gettext.h"
 
 /*** function declarations ***************************************************/
 
