@@ -1,5 +1,5 @@
 /*
- * $Id: st-bookmarks.c,v 1.30.2.1 2004/05/11 10:54:34 jylefort Exp $
+ * $Id: st-bookmarks.c,v 1.30.2.2 2004/05/11 15:40:41 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,8 +32,8 @@
  */
 
 #include "config.h"
-#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
+#include "gettext.h"
 #include "art/bookmarks.h"
 #include "sg-util.h"
 #include "sgtk-util.h"
