@@ -1,5 +1,5 @@
 /*
- * $Id: st-browser-tab.h,v 1.27.2.1 2004/02/07 18:37:12 jylefort Exp $
+ * $Id: st-browser-tab.h,v 1.41 2004/03/27 21:54:23 jylefort Exp $
  *
  * Copyright (c) 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -35,9 +35,10 @@
 #define _ST_BROWSER_TAB_H
 
 #include <gtk/gtk.h>
-#include "st-category.h"
 #include "st-handler.h"
 #include "st-thread.h"
+#include "st-category-view.h"
+#include "st-stream-view.h"
 
 #define ST_TYPE_BROWSER_TAB			(st_browser_tab_get_type())
 #define ST_BROWSER_TAB(obj)			(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_BROWSER_TAB, STBrowserTab))
@@ -46,52 +47,43 @@
 #define ST_IS_BROWSER_TAB_CLASS(klass)		(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_BROWSER_TAB))
 #define ST_BROWSER_TAB_GET_CLASS(obj)		(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_BROWSER_TAB, STBrowserTabClass))
 
+typedef struct _STBrowserTabPrivate STBrowserTabPrivate;
+
 typedef struct
 {
   GtkHPaned			paned;
   
-  GtkWidget			*window;		/* our parent STBrowserWindow */
+  STBrowserTabPrivate		*priv;
 
-  GSList			*labels;		/* a list of tab labels */
-
-  STHandler			*handler;		/* public */
-  GtkWidget			*statusbar;		/* public */
-  int				statusbar_depth;
+  STHandler			*handler;
+  GtkWidget			*statusbar;
 
   gboolean			refreshing;
 
-  STThread			*thread;
-
-  GtkWidget			*category_scrolled;
-  GtkWidget			*category_view;		/* public */
-
-  GtkWidget			*stream_scrolled;
-  GtkWidget			*stream_view;		/* public */
+  STCategoryView		*category_view;
+  STStreamView			*stream_view;
 } STBrowserTab;
 
 typedef struct
 {
-  GtkHPanedClass	parent_class;
+  GtkHPanedClass		parent_class;
+
+  /* signals */
+  void (*refreshing_changed) (STBrowserTab *tab, gboolean refreshing);
 } STBrowserTabClass;
 
 GType		st_browser_tab_get_type		(void);
-GtkWidget	*st_browser_tab_new		(GtkWidget	*window,
-						 STHandler	*handler);
-GtkWidget	*st_browser_tab_get_label	(STBrowserTab	*tab);
+GtkWidget	*st_browser_tab_new		(STHandler	*handler);
+GtkWidget	*st_browser_tab_get_label	(STBrowserTab	*tab,
+						 gboolean	use_event_box);
 void		st_browser_tab_set_label_icon_visible (STBrowserTab *tab,
 						       gboolean     visible);
 
 void		st_browser_tab_update_sensitivity (STBrowserTab	*tab);
 
-gboolean	st_browser_tab_is_empty		(STBrowserTab	*tab);
-
 void		st_browser_tab_refresh		(STBrowserTab	*tab);
 void		st_browser_tab_update		(STBrowserTab	*tab);
-void		st_browser_tab_abort		(STBrowserTab	*tab);
 gboolean	st_browser_tab_can_stop		(STBrowserTab	*tab);
 void		st_browser_tab_stop		(STBrowserTab	*tab);
 
-void		st_browser_tab_category_selected	(STBrowserTab	*tab);
-void		st_browser_tab_streams_selected		(STBrowserTab	*tab);
-
 #endif /* _ST_BROWSER_TAB_H */
