@@ -1,5 +1,5 @@
 /*
- * $Id: st-config-load.c,v 1.35.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-config-load.c,v 1.35.2.2 2004/05/11 15:40:41 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -34,8 +34,8 @@
 #include "config.h"
 #include <string.h>
 #include <stdlib.h>
-#include <glib/gi18n-lib.h>
 #include <glib-object.h>
+#include "gettext.h"
 #include "sg-parser.h"
 #include "st-handler.h"
 #include "st-handler-field.h"
