@@ -1,5 +1,5 @@
 /*
- * $Id: st-general-tab.c,v 1.27.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-general-tab.c,v 1.27.2.2 2004/05/11 15:40:41 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,9 +32,9 @@
  */
 
 #include "config.h"
-#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include "art/general_preferences.h"
+#include "gettext.h"
 #include "sgtk-hig.h"
 #include "st-general-tab.h"
 #include "st-preferences.h"
