@@ -1,5 +1,5 @@
 /*
- * $Id: st-plugins.c,v 1.14.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-plugins.c,v 1.14.2.2 2004/05/11 15:40:42 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -33,9 +33,9 @@
 
 #include "config.h"
 #include <glib.h>
-#include <glib/gi18n-lib.h>
 #include <gmodule.h>
 #include <string.h>
+#include "gettext.h"
 #include "st-plugin.h"
 #include "st-plugins.h"
 #include "st-dialog-api.h"
