@@ -1,5 +1,5 @@
 /*
- * $Id: st-programs.c,v 1.9.4.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-programs.c,v 1.9.4.2 2004/05/11 15:40:42 jylefort Exp $
  *
  * Copyright (c) 2002, 2003 Jean-Yves Lefort
  * All rights reserved.
@@ -33,7 +33,7 @@
 
 #include "config.h"
 #include <glib.h>
-#include <glib/gi18n-lib.h>
+#include "gettext.h"
 #include "sg-util.h"
 #include "st-thread.h"
 #include "st-action.h"
