@@ -1,5 +1,5 @@
 /*
- * $Id: st-shell.c,v 1.170.2.2 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-shell.c,v 1.170.2.3 2004/05/11 15:40:42 jylefort Exp $
  *
  * Copyright (c) 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -32,10 +32,10 @@
  */
 
 #include "config.h"
-#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include "art/streamtuner.h"
+#include "gettext.h"
 #include "sg-util.h"
 #include "sgtk-hig.h"
 #include "sgtk-util.h"
