@@ -1,5 +1,5 @@
 /*
- * $Id: st-thread.c,v 1.33.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-thread.c,v 1.33.2.2 2004/05/11 15:40:42 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -35,7 +35,7 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <glib.h>
-#include <glib/gi18n-lib.h>
+#include "gettext.h"
 #include "st-dialog-api.h"
 #include "st-thread.h"
 #include "st-handler.h"
