@@ -1,5 +1,5 @@
 /*
- * $Id: st-transfer.c,v 1.73.2.1 2004/05/11 10:54:35 jylefort Exp $
+ * $Id: st-transfer.c,v 1.73.2.2 2004/05/11 15:40:42 jylefort Exp $
  *
  * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
  * All rights reserved.
@@ -34,8 +34,8 @@
 #include "config.h"
 #include <string.h>
 #include <curl/curl.h>
-#include <glib/gi18n-lib.h>
 #include <gtk/gtk.h>
+#include "gettext.h"
 #include "sg-util.h"
 #include "sgtk-auth-dialog.h"
 #include "st-dialog-api.h"
